@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package Text::Parser::Multiline 0.802;
+package Text::Parser::Multiline 0.803;
 
 # ABSTRACT: Adds multi-line support to the Text::Parser object.
 
@@ -11,8 +11,7 @@ our (@EXPORT)    = ();
 use Role::Tiny;
 
 
-requires(
-    qw(save_record setting lines_parsed has_aborted __read_file_handle),
+requires( qw(save_record setting lines_parsed has_aborted __read_file_handle),
     qw(join_last_line is_line_continued) );
 
 use Exception::Class (
@@ -64,8 +63,9 @@ sub __around_is_line_part_of_last {
 }
 
 sub __after__read_file_handle {
-    my $self      = shift;
-    return $self->__after_at_eof() if $self->setting('multiline_type') eq 'join_next';
+    my $self = shift;
+    return $self->__after_at_eof()
+        if $self->setting('multiline_type') eq 'join_next';
     my $last_line = $self->__pop_last_line();
     $orig_save_record->( $self, $last_line ) if defined $last_line;
 }
@@ -121,7 +121,7 @@ sub __stash_line {
 
 sub __pop_last_line {
     my $self = shift;
-    return undef if not exists $self->{__temp_joined_line};
+    return if not exists $self->{__temp_joined_line};
     my $last_line = $self->{__temp_joined_line};
     delete $self->{__temp_joined_line};
     return $last_line;
@@ -141,7 +141,7 @@ Text::Parser::Multiline - Adds multi-line support to the Text::Parser object.
 
 =head1 VERSION
 
-version 0.802
+version 0.803
 
 =head1 SYNOPSIS
 
